==> bunny_sdk-0.0.13.tar.gz: bunny_sdk-0.0.13/bunny_sdk/edge_storage_api_client/edge_storage_api_client.py <==
from __future__ import annotations
from kiota_abstractions.api_client_builder import enable_backing_store_for_serialization_writer_factory, register_default_deserializer, register_default_serializer
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.serialization import ParseNodeFactoryRegistry, SerializationWriterFactoryRegistry
from kiota_serialization_form.form_parse_node_factory import FormParseNodeFactory
from kiota_serialization_form.form_serialization_writer_factory import FormSerializationWriterFactory
from kiota_serialization_json.json_parse_node_factory import JsonParseNodeFactory
from kiota_serialization_json.json_serialization_writer_factory import JsonSerializationWriterFactory
from kiota_serialization_multipart.multipart_serialization_writer_factory import MultipartSerializationWriterFactory
from kiota_serialization_text.text_parse_node_factory import TextParseNodeFactory
from kiota_serialization_text.text_serialization_writer_factory import TextSerializationWriterFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .item.with_storage_zone_name_item_request_builder import WithStorageZoneNameItemRequestBuilder

class EdgeStorageApiClient(BaseRequestBuilder):
    """
    The main entry point of the SDK, exposes the configuration and the fluent API.
    """
    def __init__(self,request_adapter: RequestAdapter) -> None:
        """
        Instantiates a new EdgeStorageApiClient and sets the default values.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        if request_adapter is None:
            raise TypeError("request_adapter cannot be null.")
        super().__init__(request_adapter, "{+baseurl}", None)
        register_default_serializer(JsonSerializationWriterFactory)
        register_default_serializer(TextSerializationWriterFactory)
        register_default_serializer(FormSerializationWriterFactory)
        register_default_serializer(MultipartSerializationWriterFactory)
        register_default_deserializer(JsonParseNodeFactory)
        register_default_deserializer(TextParseNodeFactory)
        register_default_deserializer(FormParseNodeFactory)
        if not self.request_adapter.base_url:
            self.request_adapter.base_url = "https://{region}.bunnycdn.com"
        self.path_parameters["base_url"] = self.request_adapter.base_url
    
    def by_storage_zone_name(self,storage_zone_name: str) -> WithStorageZoneNameItemRequestBuilder:
        """
        Gets an item from the EdgeStorageApiClient.item collection
        param storage_zone_name: the name of your storage zone where you are connecting to.
        Returns: WithStorageZoneNameItemRequestBuilder
        """
        if storage_zone_name is None:
            raise TypeError("storage_zone_name cannot be null.")
        from .item.with_storage_zone_name_item_request_builder import WithStorageZoneNameItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["storageZoneName"] = storage_zone_name
        return WithStorageZoneNameItemRequestBuilder(self.request_adapter, url_tpl_params)

==> bunny_sdk-0.0.15.tar.gz: bunny_sdk-0.0.15/bunny_sdk/edge_storage_api_client/edge_storage_api_client.py <==
from __future__ import annotations
from kiota_abstractions.api_client_builder import enable_backing_store_for_serialization_writer_factory, register_default_deserializer, register_default_serializer
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.serialization import ParseNodeFactoryRegistry, SerializationWriterFactoryRegistry
from kiota_serialization_form.form_parse_node_factory import FormParseNodeFactory
from kiota_serialization_form.form_serialization_writer_factory import FormSerializationWriterFactory
from kiota_serialization_json.json_parse_node_factory import JsonParseNodeFactory
from kiota_serialization_json.json_serialization_writer_factory import JsonSerializationWriterFactory
from kiota_serialization_multipart.multipart_serialization_writer_factory import MultipartSerializationWriterFactory
from kiota_serialization_text.text_parse_node_factory import TextParseNodeFactory
from kiota_serialization_text.text_serialization_writer_factory import TextSerializationWriterFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .item.with_storage_zone_name_item_request_builder import WithStorageZoneNameItemRequestBuilder

class EdgeStorageApiClient(BaseRequestBuilder):
    """
    The main entry point of the SDK, exposes the configuration and the fluent API.
    """
    def __init__(self,request_adapter: RequestAdapter) -> None:
        """
        Instantiates a new EdgeStorageApiClient and sets the default values.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        if request_adapter is None:
            raise TypeError("request_adapter cannot be null.")
        super().__init__(request_adapter, "{+baseurl}", None)
        register_default_serializer(JsonSerializationWriterFactory)
        register_default_serializer(TextSerializationWriterFactory)
        register_default_serializer(FormSerializationWriterFactory)
        register_default_serializer(MultipartSerializationWriterFactory)
        register_default_deserializer(JsonParseNodeFactory)
        register_default_deserializer(TextParseNodeFactory)
        register_default_deserializer(FormParseNodeFactory)
        if not self.request_adapter.base_url:
            self.request_adapter.base_url = "https://{region}.bunnycdn.com"
        self.path_parameters["base_url"] = self.request_adapter.base_url
    
    def by_storage_zone_name(self,storage_zone_name: str) -> WithStorageZoneNameItemRequestBuilder:
        """
        Gets an item from the EdgeStorageApiClient.item collection
        param storage_zone_name: The name of your storage zone where you are connecting to.
        Returns: WithStorageZoneNameItemRequestBuilder
        """
        if storage_zone_name is None:
            raise TypeError("storage_zone_name cannot be null.")
        from .item.with_storage_zone_name_item_request_builder import WithStorageZoneNameItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["storageZoneName"] = storage_zone_name
        return WithStorageZoneNameItemRequestBuilder(self.request_adapter, url_tpl_params)
